@@ -1,7 +1,7 @@
 # =====================================
 # generator=datazen
-# version=1.4.2
-# hash=a6753f51d42ab828874d2d0c60383221
+# version=1.9.0
+# hash=92dbbff95ef12dc6eeee47b63eb81f7e
 # =====================================
 
 """
@@ -9,12 +9,20 @@ datazen - Useful defaults and other package metadata.
 """
 
 PKG_NAME = "datazen"
-VERSION = "1.4.3"
+VERSION = "1.9.0"
 DESCRIPTION = "Compile and render schema-validated configuration data."
 
 DEFAULT_TYPE = "yaml"
-DEFAULT_MANIFEST = "manifest.{}".format(DEFAULT_TYPE)
-DEFAULT_DIR = "{}-out".format(PKG_NAME)
+DEFAULT_MANIFEST = f"manifest.{DEFAULT_TYPE}"
+DEFAULT_DIR = f"{PKG_NAME}-out"
 CACHE_SUFFIX = "_cache"
 GLOBAL_KEY = "global"
-ROOT_NAMESPACE = "__root__"
+
+
+def to_private(input_str: str) -> str:
+    """Convert some input to a 'private' String."""
+
+    return f"__{input_str}__"
+
+
+ROOT_NAMESPACE = to_private("root")
