@@ -1,4 +1,3 @@
-
 """
 datazen - A class for storing metadata about files that have been loaded.
 """
@@ -10,56 +9,65 @@ import logging
 import os
 import shutil
 import time
-from typing import Dict, List, Tuple
+from typing import Dict, List
 
 # internal
 from datazen import VERSION
 from datazen.parsing import set_file_hash, dedup_dict_lists
-from datazen.load import load_dir_only
-from datazen.compile import str_compile
+from datazen.load import load_dir_only, LoadedFiles
+from datazen.compile import write_dir
 
 LOG = logging.getLogger(__name__)
 
-DATA_DEFAULT = {"hashes": defaultdict(lambda: defaultdict(dict)),
-                "loaded": defaultdict(list),
-                "meta": {"version": VERSION}}
+DATA_DEFAULT = {
+    "hashes": defaultdict(lambda: defaultdict(dict)),
+    "loaded": defaultdict(list),
+    "meta": {"version": VERSION},
+}
 
 
 class FileInfoCache:
-    """ Provides storage for file hashes and lists that have been loaded. """
+    """Provides storage for file hashes and lists that have been loaded."""
 
-    def __init__(self, cache_dir: str = None):
-        """ Construct an empty cache or optionally load from a directory. """
+    def __init__(
+        self,
+        cache_dir: str = None,
+        logger: logging.Logger = LOG,
+    ) -> None:
+        """Construct an empty cache or optionally load from a directory."""
 
         self.data: dict = deepcopy(DATA_DEFAULT)
         self.removed_data: Dict[str, List[str]] = defaultdict(list)
         self.cache_dir: str = ""
         if cache_dir is not None:
             self.load(cache_dir)
+        self.logger = logger
 
     def load(self, cache_dir: str) -> None:
-        """ Load data from a directory. """
+        """Load data from a directory."""
 
         assert self.cache_dir == ""
         self.cache_dir = cache_dir
         os.makedirs(self.cache_dir, exist_ok=True)
 
         # reject things that don't belong by updating instead of assigning
-        new_data = sync_cache_data(load_dir_only(self.cache_dir, True),
-                                   self.removed_data)
+        new_data = sync_cache_data(
+            load_dir_only(self.cache_dir, True), self.removed_data
+        )
         for key in DATA_DEFAULT:
             self.data[key].update(new_data[key])
 
     def get_hashes(self, sub_dir: str) -> Dict[str, dict]:
-        """ Get the cached, dictionary of file hashes for a certain key. """
+        """Get the cached, dictionary of file hashes for a certain key."""
 
         return self.data["hashes"][sub_dir]
 
-    def check_hit(self, sub_dir: str, path: str,
-                  also_cache: bool = True) -> bool:
+    def check_hit(
+        self, sub_dir: str, path: str, also_cache: bool = True
+    ) -> bool:
         """
         Determine if a given file already exists with its current hash in the
-        cache, if not return False and optionally add it to the cache. """
+        cache, if not return False and optionally add it to the cache."""
 
         abs_path = os.path.abspath(path)
         is_new = set_file_hash(self.get_hashes(sub_dir), abs_path, also_cache)
@@ -72,12 +80,12 @@ class FileInfoCache:
         return not is_new
 
     def get_loaded(self, sub_dir: str) -> List[str]:
-        """ Get the cached, list of loaded files for a certain key. """
+        """Get the cached, list of loaded files for a certain key."""
 
         return self.data["loaded"][sub_dir]
 
     def describe(self) -> None:
-        """ Describe this cache's contents for debugging purposes. """
+        """Describe this cache's contents for debugging purposes."""
 
         curr_dir = os.getcwd()
         for hash_set, hash_data in self.data["hashes"].items():
@@ -86,58 +94,64 @@ class FileInfoCache:
             for filename, hash_item in hash_data.items():
                 total += 1
                 if curr_dir in filename:
-                    filename = filename[len(curr_dir) + 1:]
+                    filename = filename[len(curr_dir) + 1 :]
                 if not self.check_hit(hash_set, filename, False):
                     misses.append((filename, hash_item))
                 else:
-                    LOG.debug("%s (%s) matched", filename,
-                              time_str(hash_item["time"]))
+                    self.logger.debug(
+                        "%s (%s) matched",
+                        filename,
+                        time_str(hash_item["time"]),
+                    )
 
             # log all misses / updates
             for miss in misses:
-                LOG.info("%s (%s) updated", miss[0], time_str(miss[1]["time"]))
+                self.logger.info(
+                    "%s (%s) updated", miss[0], time_str(miss[1]["time"])
+                )
             for removed in self.removed_data[hash_set]:
-                LOG.info("%s no longer present", removed)
+                self.logger.info("%s no longer present", removed)
 
             # log a summary
-            LOG.info("%s: %d/%d match", hash_set,
-                     total - (len(misses) + len(self.removed_data[hash_set])),
-                     total)
+            self.logger.info(
+                "%s: %d/%d match",
+                hash_set,
+                total - (len(misses) + len(self.removed_data[hash_set])),
+                total,
+            )
 
         # describe metadata
         if "meta" in self.data:
-            LOG.info("version: %s (current: %s)",
-                     self.data["meta"]["version"], VERSION)
+            self.logger.info(
+                "version: %s (current: %s)",
+                self.data["meta"]["version"],
+                VERSION,
+            )
 
-    def get_data(self, name: str) -> Tuple[List[str], Dict[str, dict]]:
-        """ Get the tuple version of cached data. """
+    def get_data(self, name: str) -> LoadedFiles:
+        """Get the tuple version of cached data."""
 
-        return (self.get_loaded(name), self.get_hashes(name))
+        return LoadedFiles(self.get_loaded(name), self.get_hashes(name))
 
     def clean(self) -> None:
-        """ Remove cached data from the file-system. """
+        """Remove cached data from the file-system."""
 
         self.data = deepcopy(DATA_DEFAULT)
         if self.cache_dir != "":
             shutil.rmtree(self.cache_dir)
-            os.makedirs(self.cache_dir, exist_ok=True)
-            LOG.info("cleaning cache at '%s'", self.cache_dir)
+            self.logger.info("cleaning cache at '%s'", self.cache_dir)
 
     def write(self, out_type: str = "json") -> None:
-        """ Commit cached data to the file-system. """
+        """Commit cached data to the file-system."""
 
         if self.cache_dir != "":
             data = sync_cache_data(self.data, self.removed_data)
-            for key, val in data.items():
-                key_path = os.path.join(self.cache_dir,
-                                        "{}.{}".format(key, out_type))
-                with open(key_path, "w") as key_file:
-                    key_file.write(str_compile(val, out_type))
-            LOG.debug("wrote cache to '%s'", self.cache_dir)
+            write_dir(self.cache_dir, data, out_type)
+            self.logger.debug("wrote cache to '%s'", self.cache_dir)
 
 
 def copy(cache: FileInfoCache) -> FileInfoCache:
-    """ Copy one cache into a new one. """
+    """Copy one cache into a new one."""
 
     new_cache = FileInfoCache()
 
@@ -150,7 +164,7 @@ def copy(cache: FileInfoCache) -> FileInfoCache:
 
 
 def meld(cache_a: FileInfoCache, cache_b: FileInfoCache) -> None:
-    """ Promote all updates from cache_b into cache_a. """
+    """Promote all updates from cache_b into cache_a."""
 
     # aggregates new files
     a_load = cache_a.data["loaded"]
@@ -176,20 +190,23 @@ def meld(cache_a: FileInfoCache, cache_b: FileInfoCache) -> None:
                 else:
                     a_data = a_hash[key][item]
                     b_data = b_hash[key][item]
-                    if (b_data["hash"] != a_data["hash"] and
-                            b_data["time"] > a_data["time"]):
+                    if (
+                        b_data["hash"] != a_data["hash"]
+                        and b_data["time"] > a_data["time"]
+                    ):
                         a_data["hash"] = b_data["hash"]
                         a_data["time"] = b_data["time"]
 
 
 def time_str(time_s: float) -> str:
-    """ Concert a timestamp to a String. """
+    """Concert a timestamp to a String."""
 
     return time.strftime("%c", time.localtime(time_s))
 
 
-def cmp_loaded_count(cache_a: FileInfoCache, cache_b: FileInfoCache,
-                     name: str) -> int:
+def cmp_loaded_count(
+    cache_a: FileInfoCache, cache_b: FileInfoCache, name: str
+) -> int:
     """
     Compute the total difference in file counts (for a named group)
     between two caches.
@@ -212,8 +229,9 @@ def cmp_loaded_count(cache_a: FileInfoCache, cache_b: FileInfoCache,
     return result
 
 
-def cmp_loaded_count_from_set(cache_a: FileInfoCache, cache_b: FileInfoCache,
-                              name: str, files: List[str]) -> int:
+def cmp_loaded_count_from_set(
+    cache_a: FileInfoCache, cache_b: FileInfoCache, name: str, files: List[str]
+) -> int:
     """
     Count the number of files uniquely loaded to one cache but not the other.
     """
@@ -228,9 +246,13 @@ def cmp_loaded_count_from_set(cache_a: FileInfoCache, cache_b: FileInfoCache,
     return result
 
 
-def cmp_total_loaded(cache_a: FileInfoCache, cache_b: FileInfoCache,
-                     known_types: List[str],
-                     load_checks: Dict[str, List[str]] = None) -> int:
+def cmp_total_loaded(
+    cache_a: FileInfoCache,
+    cache_b: FileInfoCache,
+    known_types: List[str],
+    load_checks: Dict[str, List[str]] = None,
+    logger: logging.Logger = LOG,
+) -> int:
     """
     Compute the total difference in file counts for a provided set of named
     groups.
@@ -239,22 +261,28 @@ def cmp_total_loaded(cache_a: FileInfoCache, cache_b: FileInfoCache,
     result = 0
     for known in known_types:
         if load_checks is not None and known in load_checks:
-            iter_result = cmp_loaded_count_from_set(cache_a, cache_b, known,
-                                                    load_checks[known])
+            iter_result = cmp_loaded_count_from_set(
+                cache_a, cache_b, known, load_checks[known]
+            )
             if iter_result > 0:
-                LOG.info("%d changes detected for '%s' in '%s'", iter_result,
-                         known, load_checks[known])
+                logger.info(
+                    "%d changes detected for '%s' in '%s'",
+                    iter_result,
+                    known,
+                    load_checks[known],
+                )
             result += iter_result
         else:
             iter_result = cmp_loaded_count(cache_a, cache_b, known)
             if iter_result > 0:
-                LOG.info("%d changes detected for '%s'", iter_result, known)
+                logger.info("%d changes detected for '%s'", iter_result, known)
             result += iter_result
     return result
 
 
-def sync_cache_data(cache_data: dict,
-                    removed_data: Dict[str, List[str]]) -> dict:
+def sync_cache_data(
+    cache_data: dict, removed_data: Dict[str, List[str]]
+) -> dict:
     """
     Before writing a cache to disk we want to de-duplicate items in the loaded
     list and remove hash data for files that were removed so that if they
@@ -267,9 +295,10 @@ def sync_cache_data(cache_data: dict,
     return data
 
 
-def remove_missing_hashed_files(data: dict,
-                                removed_data: Dict[str, List[str]]) -> dict:
-    """ Assign new hash data based on the files that are still present. """
+def remove_missing_hashed_files(
+    data: dict, removed_data: Dict[str, List[str]]
+) -> dict:
+    """Assign new hash data based on the files that are still present."""
 
     for category in data.keys():
         new_data = {}
