@@ -1,4 +1,3 @@
-
 """
 datazen - A dict wrapper that enables simpler schema validation.
 """
@@ -8,9 +7,7 @@ import logging
 from collections import UserDict
 
 # third-party
-from cerberus import Validator  # type: ignore
-
-LOG = logging.getLogger(__name__)
+from cerberus import Validator
 
 
 class ValidDict(UserDict):
@@ -19,8 +16,14 @@ class ValidDict(UserDict):
     enforced.
     """
 
-    def __init__(self, name: str, data: dict, schema: Validator):
-        """ Initialize a named, ValidDict. """
+    def __init__(
+        self,
+        name: str,
+        data: dict,
+        schema: Validator,
+        logger: logging.Logger = logging.getLogger(__name__),
+    ) -> None:
+        """Initialize a named, ValidDict."""
 
         # initialize the dict
         if not isinstance(data, dict):
@@ -30,8 +33,12 @@ class ValidDict(UserDict):
         self.name = name
         self.validator = schema
         self.valid = self.validator.validate(self.data)
+        self.logger = logger
         if not self.valid:
-            LOG.error("validation error(s) for '%s': %s", self.name,
-                      self.validator.errors)
-            LOG.error("data: %s", data)
-            LOG.error("schema: %s", schema.schema)
+            self.logger.error(
+                "validation error(s) for '%s': %s",
+                self.name,
+                self.validator.errors,
+            )
+            self.logger.error("data: %s", data)
+            self.logger.error("schema: %s", schema.schema)
