@@ -1,4 +1,3 @@
-
 """
 datazen - A command implementation for compiling configuration data and
           variables into a single, monolithic output.
@@ -9,15 +8,20 @@ import logging
 from typing import List
 
 # internal
-from datazen.classes.environment import Environment
+from datazen.environment.integrated import Environment
 from datazen.parsing import get_file_ext
 from datazen.compile import str_compile
 
 LOG = logging.getLogger(__name__)
 
 
-def cmd_compile(config_dirs: List[str], schema_dirs: List[str],
-                variable_dirs: List[str], output_file_path: str) -> bool:
+def cmd_compile(
+    config_dirs: List[str],
+    schema_dirs: List[str],
+    variable_dirs: List[str],
+    output_file_path: str,
+    logger: logging.Logger = LOG,
+) -> bool:
     """
     Load configuration data by resolving variables and validating provided
     schemas. Write the result to the specified output file, inferring the type
@@ -42,13 +46,14 @@ def cmd_compile(config_dirs: List[str], schema_dirs: List[str],
     # serialize the data
     result = str_compile(configs, ext)
     if not result:
-        LOG.error("can't write '%s' data to '%s', no output", ext,
-                  output_file_path)
+        logger.error(
+            "can't write '%s' data to '%s', no output", ext, output_file_path
+        )
         return False
 
     # write the output
-    with open(output_file_path, "w") as output:
+    with open(output_file_path, "w", encoding="utf-8") as output:
         output.write(result)
-    LOG.info("wrote '%s' configuration data to '%s'", ext, output_file_path)
+    logger.info("wrote '%s' configuration data to '%s'", ext, output_file_path)
 
     return True
